// SPDX-FileCopyrightText: 2023 Aravinth Manivannan <realaravinth@batsense.net>
//
// SPDX-License-Identifier: AGPL-3.0-or-later

use reqwest::Client;
use serde::Serialize;
use serde::Deserialize;

use crate::user::User;

#[derive(Clone, Debug, Eq, PartialEq, Serialize, Deserialize)]
pub enum ChildComment {
    Comment(Box<Comment>),
}

#[derive(Clone, Debug, Eq, PartialEq, Serialize, Deserialize)]
pub struct Comment {
    by: String,
    id: usize,
    kids: Option<Vec<usize>>,
    #[serde(rename(deserialize = "type"))]
    item_type: String,
    parent: Option<usize>,
    time: usize,

}

pub async fn get_user_comments(c: &Client, u:&User) -> Vec<Comment> {
let mut comments = Vec::default();
for item in u.submitted.iter() {
    let comment: Comment = c.get(&format!("https://hacker-news.firebaseio.com/v0/item/{item}.json")).send().await.unwrap().json().await.unwrap();
    if comment.item_type == "comment" {
        comments.push(comment);
    }

}
comments
}
